@@ -8,6 +8,9 @@ use IO::File;
 use strict;
 use SelectSaver;
 require Net::LDAP::Entry;
+use vars qw($VERSION);
+
+$VERSION = "0.02";
 
 sub new {
   my $pkg = shift;
@@ -70,6 +73,10 @@ sub _read_one {
   my $attr;
   foreach $line (@ldif) {
     $line =~ s/^(\w+):\s*// && ($attr = $1) or next;
+    if($line =~ s/^:\s*//) {
+      require MIME::Base64;
+      $line = MIME::Base64::decode($line);
+    }
     if ($attr eq $last) {
       push @$vals, $line;
       next;
